# 開始！

歡迎來到Rapunzel，這是一個現代化的Python和R 開發環境。以下是一些方便的鍵盤快捷方式。

## 處理項目資料夾和文件

- [`Ctrl+Shift+O`：打開項目資料夾](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`：從項目資料夾打開文件](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`：創建空白文件](opensesame://event.ide_new_file)

## 快速完成操作

- [`Ctrl+Shift+P`：激活命令調色板](opensesame://event.command_palette_activate)
- `Ctrl+R`：跳轉到功能或類別

## 運行代碼

- `F5`：運行項目或文件
- `F9`：運行選擇、單元或當前行